#include "dp_displaywidget.h"
#include "ui_dp_displaywidget.h"
#include "ofd_reader.h"
#include "widgets/dw_propertyvpre.h"

DP_DisplayWidget::DP_DisplayWidget(QWidget *parent, OFD_Reader* pReader) :
    DW_BaseSetWidget(parent, pReader),
    ui(new Ui::DP_DisplayWidget)
{
    ui->setupUi(this);
    m_pVPreferences = m_pReader->GetVPreferences();
    DF_Settings* pSettings = m_pReader->GetSettings();
    m_iBackColor = 0xeaeaea;
    pSettings->GetConfigRgbValue(DF_SET_DISPLAY_BACKCOLOR, m_iBackColor);
}
DP_DisplayWidget::~DP_DisplayWidget()
{
    delete ui;
}
void DP_DisplayWidget::_InitUI()
{
    //comboBox_PageMode
    ui->label_PageMode->setText(DW_PropertyVPre::tr("PageMode:"));
    ui->comboBox_PageMode->addItem(DW_PropertyVPre::tr("Default"));
    ui->comboBox_PageMode->addItem(DW_PropertyVPre::tr("FullScreen"));
    ui->comboBox_PageMode->addItem(DW_PropertyVPre::tr("UseOutlines"));
    ui->comboBox_PageMode->addItem(DW_PropertyVPre::tr("UseThumbs"));
    ui->comboBox_PageMode->addItem(DW_PropertyVPre::tr("UseCustomTags"));
    ui->comboBox_PageMode->addItem(DW_PropertyVPre::tr("UseLayers"));
    ui->comboBox_PageMode->addItem(DW_PropertyVPre::tr("UseAttatchs"));
    ui->comboBox_PageMode->addItem(DW_PropertyVPre::tr("UseBookmarks"));
    ui->comboBox_PageMode->setCurrentIndex((int)m_pVPreferences->GetPageMode());

    //comboBox_PageLayout
    ui->label_PageLayout->setText(DW_PropertyVPre::tr("PageLayout:"));
    ui->comboBox_PageLayout->addItem(DW_PropertyVPre::tr("OnePage"));
    ui->comboBox_PageLayout->addItem(DW_PropertyVPre::tr("OneColumn"));
    ui->comboBox_PageLayout->addItem(DW_PropertyVPre::tr("TwoPageL"));
    ui->comboBox_PageLayout->addItem(DW_PropertyVPre::tr("TwoColumnL"));
    ui->comboBox_PageLayout->addItem(DW_PropertyVPre::tr("TwoPageR"));
    ui->comboBox_PageLayout->addItem(DW_PropertyVPre::tr("TwoColumnR"));
    int iPageLayout = (int)m_pVPreferences->GetLayoutMode();
    if ( iPageLayout >= (int)DF_LAYOUTMODE_DOUBLE_FLOW_RIGHT )
        iPageLayout = (int)DF_LAYOUTMODE_SINGLE_FLOW;

    ui->comboBox_PageLayout->setCurrentIndex(iPageLayout);

    //comboBox_ZoomMode
    ui->label_ZoomMode->setText(DW_PropertyVPre::tr("ZoomMode:"));
    ui->comboBox_ZoomMode->addItem(DW_PropertyVPre::tr("Default"));
    ui->comboBox_ZoomMode->addItem(DW_PropertyVPre::tr("Original"));
    ui->comboBox_ZoomMode->addItem(DW_PropertyVPre::tr("FitWidth"));
    ui->comboBox_ZoomMode->addItem(DW_PropertyVPre::tr("FitHeight"));
    ui->comboBox_ZoomMode->addItem(DW_PropertyVPre::tr("FitRect"));
    ui->comboBox_ZoomMode->setCurrentIndex((int)m_pVPreferences->GetZoomMode());

    //zoom
    ui->label_Zoom->setText(DW_PropertyVPre::tr("Zoom:"));
    ui->doubleSpinBox_Zoom->setRange(10, 6400);
    ui->doubleSpinBox_Zoom->setSingleStep(1);
    ui->doubleSpinBox_Zoom->setDecimals(1);
    ui->doubleSpinBox_Zoom->setValue(m_pVPreferences->GetZoom() * 100);
    _UpdateZoomUnable();

    //backcolor
    SetButtonColor(ui->pushButton_BackColor, m_iBackColor);
}
void DP_DisplayWidget::_SaveModify(int iFlag)
{
    if ( !m_bModify )
        return;

    //VPreferences
    m_pVPreferences->SetPageMode((DF_PageMode)ui->comboBox_PageMode->currentIndex());
    m_pVPreferences->SetLayoutMode((DF_LayoutMode)ui->comboBox_PageLayout->currentIndex());
    m_pVPreferences->SetZoomMode((DF_ZoomMode)ui->comboBox_ZoomMode->currentIndex());
    if ( ui->comboBox_ZoomMode->currentIndex() == 0 )
    {
        float fValue = ui->doubleSpinBox_Zoom->value() / 100;
        m_pVPreferences->SetZoom(fValue);
    }
    else
    {
        m_pVPreferences->SetZoom(1);
    }
    m_pVPreferences->Save2Settings(m_pReader);

    //diaplay
    DF_Settings* pSettings = m_pReader->GetSettings();
    int iSetColor;
    pSettings->GetConfigIntValue(DF_SET_DISPLAY_BACKCOLOR, iSetColor);
    if ( iSetColor != (int)m_iBackColor )
    {
        pSettings->SetConfigIntValue(DF_SET_DISPLAY_BACKCOLOR, m_iBackColor);
        m_pReader->AddParam(DF_SET_DISPLAY_BACKCOLOR, m_iBackColor);
        DF_App::Get()->Event_AppValueChanged(DFH_VALUE_REDRAW);
    }
}
void DP_DisplayWidget::_UpdateZoomUnable()
{
    if ( ui->comboBox_ZoomMode->currentIndex() == 0 )
        ui->widget_Zoom->setEnabled(true);
    else
        ui->widget_Zoom->setEnabled(false);
}
void DP_DisplayWidget::on_comboBox_PageMode_activated(int index)
{
    if ( (int)m_pVPreferences->GetPageMode() != index )
        m_bModify = true;
}
void DP_DisplayWidget::on_comboBox_PageLayout_activated(int index)
{
    if ( (int)m_pVPreferences->GetLayoutMode() != index )
        m_bModify = true;
}
void DP_DisplayWidget::on_comboBox_ZoomMode_activated(int index)
{
    if ( (int)m_pVPreferences->GetZoomMode() != index )
        m_bModify = true;

    _UpdateZoomUnable();
}
void DP_DisplayWidget::on_doubleSpinBox_Zoom_valueChanged(double arg1)
{
    int iPerZoom = m_pVPreferences->GetZoom() * 100;
    if ( qAbs(iPerZoom - arg1) > 0.1  )
        m_bModify = true;
}
void DP_DisplayWidget::on_pushButton_BackColor_clicked()
{
    QColor selColor = QColorDialog::getColor(QColor(m_iBackColor), this);
    if ( selColor.isValid() && selColor.rgb() != m_iBackColor )
    {
        m_iBackColor = selColor.rgb();
        m_bModify = true;
        SetButtonColor(ui->pushButton_BackColor, m_iBackColor);
    }
}

