#include "dp_optiondialog.h"
#include "ui_dp_optiondialog.h"
#include "dp_tabletwidget.h"
#include "dp_auxwidget.h"
#include "dp_servicewidget.h"
#include "dp_viewmarkwidget.h"
#include "dp_sealstampwidget.h"
#include "dp_convertwidget.h"
#include "dp_displaywidget.h"
#include "../dialogs/dd_messagebox.h"
#include "../framework/df_operate.h"
#include "ofd_reader.h"

DP_OptionDialog::DP_OptionDialog(OFD_Reader *pReader, QWidget *parent, const QString& sInitName) :
    DD_Dialog(pReader, parent),
    ui(new Ui::DP_OptionDialog)
{
    ui->setupUi(this);

    setWindowTitle(DP_OptionDialog::tr("Options"));
    setFixedSize(size());
    _InitUI(sInitName);
}
void    DP_OptionDialog::_InitUI(const QString& sInitName)
{
    ui->checkBox_RestoreInit->setChecked(false);
    QStringList itemList, initNameList;
    itemList << DP_OptionDialog::tr("Tablet and Pencil") << DP_OptionDialog::tr("Auxiliary") << DP_OptionDialog::tr("Service Address") \
             << DP_OptionDialog::tr("View Mark") << DP_OptionDialog::tr("Seal And Stamp") << DP_OptionDialog::tr("Convert")
             << DP_DisplayWidget::tr("Display");
    initNameList << DF_OPTION_TABLET << DF_OPTION_AUX << DF_OPTION_SERADDRESS \
                 << DF_OPTION_VIEWMARK << DF_OPTION_SEALSTAMP << DF_OPTION_CONVERT
                 << DF_OPTION_DISPLAY;
    for ( int iIndex = 0; iIndex < itemList.count(); ++iIndex )
    {
        QListWidgetItem *pListItem = new QListWidgetItem(itemList[iIndex], ui->listWidget_Options);
        QSize itemSize = pListItem->sizeHint();
        itemSize.setHeight(30);
        pListItem->setSizeHint(itemSize);
        pListItem->setData(Qt::UserRole, initNameList[iIndex]);
        ui->listWidget_Options->addItem(pListItem);
    }

    //QStackedWidget
    m_pOptionStack = new QStackedWidget(this);
    m_pOptionStack->setGeometry(190, 0, 690, 570);

    DW_BaseSetWidget* pItemWidget = new DP_TabletWidget(this, m_pReader);
    m_pOptionStack->addWidget(pItemWidget);
    pItemWidget = new DP_AuxWidget(this, m_pReader);
    m_pOptionStack->addWidget(pItemWidget);
    pItemWidget = new DP_ServiceWidget(this, m_pReader);
    m_pOptionStack->addWidget(pItemWidget);
    pItemWidget = new DP_ViewMarkWidget(this, m_pReader);
    m_pOptionStack->addWidget(pItemWidget);
    pItemWidget = new DP_SealStampWidget(this, m_pReader);
    m_pOptionStack->addWidget(pItemWidget);
    pItemWidget = new DP_ConvertWidget(this, m_pReader);
    m_pOptionStack->addWidget(pItemWidget);
    pItemWidget = new DP_DisplayWidget(this, m_pReader);
    m_pOptionStack->addWidget(pItemWidget);

//    pItemWidget = new DP_TabletWidget(this, m_pReader);
//    m_pOptionStack->addWidget(pItemWidget);

    int iInitIndex = _GetItemIndex(sInitName);
    if ( iInitIndex < 0 )
        iInitIndex = 0;

    ui->listWidget_Options->setCurrentRow(iInitIndex);
    _SelectItem(iInitIndex);
}
void    DP_OptionDialog::_SelectItem(int iIndex)
{
    if ( iIndex < 0 )
        return;

    m_pOptionStack->setCurrentIndex(iIndex);
    DW_BaseSetWidget* pOptionWidget = (DW_BaseSetWidget *)m_pOptionStack->widget(iIndex);
    pOptionWidget->InitUI();
}
int     DP_OptionDialog::_GetItemIndex(const QString& sInitName)
{
    if ( sInitName.isEmpty() )
        return -1;

    int iItemCount = ui->listWidget_Options->count();
    for ( int iIndex = 0; iIndex < iItemCount; ++iIndex )
    {
        QListWidgetItem *pListItem = ui->listWidget_Options->item(iIndex);
        if ( pListItem->data(Qt::UserRole).toString() == sInitName )
            return iIndex;
    }

    return -1;
}
DP_OptionDialog::~DP_OptionDialog()
{
    delete ui;
}
void DP_OptionDialog::on_listWidget_Options_currentItemChanged(QListWidgetItem *current, QListWidgetItem *previous)
{
    _SelectItem(ui->listWidget_Options->currentRow());
}
void DP_OptionDialog::on_pushButton_Cancel_clicked()
{
    QDialog::reject();
}
void DP_OptionDialog::on_pushButton_Ok_clicked()
{
    if ( ui->checkBox_RestoreInit->isChecked() )
    {
        int iMessageinfo = DD_MessageBox::ShowMsg(m_pReader->GetDialogParent(), QObject::tr("DJ OFD Reader"), QObject::tr("Do you want to restore the original settings?"), \
                                   (QMessageBox::Yes|QMessageBox::No|QMessageBox::Cancel), (QMessageBox::Yes));
        if ( iMessageinfo == QMessageBox::Cancel )
            return;
        
        if ( iMessageinfo == QMessageBox::Yes)
        {
            DF_Operate *pRestoreOperate = m_pReader->GetOperate("help_djrestore");
            pRestoreOperate->AddParam("type", "config");
            pRestoreOperate->PerformOperate();
            return QDialog::reject();
        }
    }

    int iCount = m_pOptionStack->count();
    for ( int iIndex = 0; iIndex < iCount; ++iIndex )
    {
        DW_BaseSetWidget* pOptionWidget = (DW_BaseSetWidget *)m_pOptionStack->widget(iIndex);
        pOptionWidget->SaveModify();
    }

    QDialog::accept();
}

