#include "dp_tabletdialog.h"
#include "ui_dp_tabletdialog.h"
#include "ofd_reader.h"

DP_TabletDialog::DP_TabletDialog(OFD_Reader *pReader,QWidget *parent) :
    DD_Dialog(pReader, parent),
    ui(new Ui::DP_TabletDialog)
{
    ui->setupUi(this);
    setWindowTitle(DP_TabletDialog::tr("PenSet"));
    DF_Settings* pSettings = m_pReader->GetSettings();
    m_iColor = pSettings->GetTabletPenColor();
    m_fPenWidth = pSettings->GetTabletPenWidth();
    setFixedSize(size());
}

DP_TabletDialog::~DP_TabletDialog()
{
    delete ui;
}

void DP_TabletDialog::_InitUI()
{
    //笔宽设置
    QLabel* pLabel1 = new QLabel(this);
    pLabel1->setText(DP_TabletDialog::tr("Pen W:"));
    pLabel1->setGeometry(25, 25, 60, 24);

    m_pWidthComBox = new QComboBox(this);
    m_pWidthComBox->setObjectName("Pen_WidthComBox");
    m_pWidthComBox->setGeometry(80, 22, 125, 28);
    m_pWidthComBox->setView(new QListView());
    m_pWidthComBox->addItem(QIcon(":/image/resources/dj/32/line_1.png"), "0.3mm");
    m_pWidthComBox->addItem(QIcon(":/image/resources/dj/32/line_2.png"), "0.5mm");
    m_pWidthComBox->addItem(QIcon(":/image/resources/dj/32/line_3.png"), "0.8mm");
    m_pWidthComBox->addItem(QIcon(":/image/resources/dj/32/line_4.png"), "1.0mm");
    m_pWidthComBox->addItem(QIcon(":/image/resources/dj/32/line_5.png"), "1.3mm");
    m_pWidthComBox->addItem(QIcon(":/image/resources/dj/32/line_8.png"), "2.0mm");
    m_pWidthComBox->addItem(QIcon(":/image/resources/dj/32/line_12.png"), "3.0mm");
    m_pWidthComBox->addItem(QIcon(":/image/resources/dj/32/line_16.png"), "4.0mm");
    m_pWidthComBox->setEditable(true);
    _UpdateWidthComboBox();
    connect(m_pWidthComBox, SIGNAL(activated(QString)), this, SLOT(on_ComboBoxActivated(QString)));
    connect(m_pWidthComBox, SIGNAL(editTextChanged(const QString &)), this, SLOT(don_WidthEditTextChanged(const QString &)));

    QLabel* pLabel2 = new QLabel(this);
    pLabel2->setText(DP_TabletDialog::tr("Pen C:"));
    pLabel2->setGeometry(25, 65, 60, 24);

    m_pColorComBox = new DW_ColorComboBox(m_iColor,this);
    m_pColorComBox->setObjectName("Pen_ColorComBox");
    m_pColorComBox->setGeometry(80, 62, 182, 28);
}

const float g_LineArray[8]={0.3, 0.5, 0.8, 1.0, 1.3, 2.0, 3.0, 4.0};
void DP_TabletDialog::_UpdateWidthComboBox()
{
    QString sPenWidth = QString::number(m_fPenWidth, 'f', 1) + "mm";
    m_pWidthComBox->setEditText(sPenWidth);
    for ( int iIndex = 0; iIndex < 8; ++iIndex )
    {
        if ( qAbs(g_LineArray[iIndex] - m_fPenWidth) < 0.01 )
        {
            m_pWidthComBox->setCurrentIndex(iIndex);
            break;
        }
    }
}
void DP_TabletDialog::don_WidthEditTextChanged(const QString &sText1)
{
    QString sText = sText1.trimmed();
    if ( sText.endsWith("mm") )
        sText = sText.remove("mm");

    if ( !sText.isEmpty() )
    {
        bool bOk;
        float fPenWidth = sText.toFloat(&bOk);
        if ( bOk )
        {
            m_fPenWidth = fPenWidth;
        }
    }
}
void DP_TabletDialog::on_ComboBoxActivated(QString sText)
{
    sText = sText.trimmed();
    if ( sText.endsWith("mm") )
        sText = sText.remove("mm");

    if ( !sText.isEmpty() )
    {
        bool bOk;
        float fPenWidth = sText.toFloat(&bOk);
        if ( bOk )
        {
            m_fPenWidth = fPenWidth;
        }
    }

    _UpdateWidthComboBox();
}

void DP_TabletDialog::on_pushButton_Ok_clicked()
{
    DF_Settings* pSettings = m_pReader->GetSettings();
    QString sPenWidth = QString::number(m_fPenWidth, 'f', 1) ;
    pSettings->SetConfigValue(DF_SET_TABLET_PENWIDTH, sPenWidth);
    int nColor = m_pColorComBox->GetSelColor();
    pSettings->SetConfigValue(DF_SET_TABLET_PENCOLOR, QString::number(nColor));
    QDialog::accept();
}

void DP_TabletDialog::on_pushButton_Exit_clicked()
{
    QDialog::reject();
}
