#include "dp_viewmarkwidget.h"
#include "ui_dp_viewmarkwidget.h"
#include "../framework/df_framework.h"
#include "dp_optiondialog.h"
#include <QColorDialog>
#include "ofd_reader.h"

DP_ViewMarkWidget::DP_ViewMarkWidget(DP_OptionDialog *parent, OFD_Reader* pReader) :
    DW_BaseSetWidget(parent, pReader),
    ui(new Ui::DP_ViewMarkWidget)
{
    ui->setupUi(this);
    m_ViewMark = *pReader->GetViewMark();
    m_ViewMark.Reload(pReader);
    m_bRotateCustomChecked = false;
    //ui->checkBox_PrintViewMark->setVisible(false);
}
DP_ViewMarkWidget::~DP_ViewMarkWidget()
{
    delete ui;
}
void    DP_ViewMarkWidget::_InitUI()
{
    m_pTypeGroup = new QButtonGroup(this);
    m_pTypeGroup->addButton(ui->radioButton_TextWatermark);
    m_pTypeGroup->addButton(ui->radioButton_ImageWatermark);

    //刷新可用状态
    _UpdateEnable();

    ui->checkBox_ShowViewMark->setChecked(m_ViewMark.m_bShowFlag);
    ui->checkBox_PrintViewMark->setChecked(m_ViewMark.m_bPrintFlag);

    //content
    ui->spinBox_FontSize->setRange(1, 50);
    _UpdateContent();

    //style
    ui->comboBox_Pattern->addItem(QObject::tr("Center"));
    ui->comboBox_Pattern->addItem(QObject::tr("Tile"));
    ui->comboBox_Pattern->addItem(QObject::tr("Position"));
    ui->doubleSpinBox_OffsetX->setSingleStep(0.1);
    ui->doubleSpinBox_OffsetX->setRange(-1000, 1000);
    ui->doubleSpinBox_OffsetY->setSingleStep(0.1);
    ui->doubleSpinBox_OffsetY->setRange(-1000, 1000);
    m_pRotateGroup = new QButtonGroup(this);
    m_pRotateGroup->addButton(ui->radioButton_Rotate0);
    m_pRotateGroup->addButton(ui->radioButton_Rotate45);
    m_pRotateGroup->addButton(ui->radioButton_Rotate45Neg);
    m_pRotateGroup->addButton(ui->radioButton_RotateCustom);
    ui->spin_Rotate->setRange(-360, 360);
    ui->spinBox_Opacity->setRange(0, 100);
    ui->horizontalSlider_Opacity->setRange(0, 100);
    connect(ui->spinBox_Opacity, SIGNAL(valueChanged(int)), ui->horizontalSlider_Opacity, SLOT(setValue(int)));
    connect(ui->horizontalSlider_Opacity, SIGNAL(valueChanged(int)), ui->spinBox_Opacity, SLOT(setValue(int)));
    _UpdateStyle();
}
void    DP_ViewMarkWidget::_UpdateEnable()
{
    if ( !m_ViewMark.m_bShowFlag && !m_ViewMark.m_bPrintFlag )
    {
        ui->groupBox_Content->setEnabled(false);
        ui->groupBox_Style->setEnabled(false);
    }
    else
    {
        ui->groupBox_Content->setEnabled(true);
        ui->groupBox_Style->setEnabled(true);
    }

    if ( m_bRotateCustomChecked )
        ui->spin_Rotate->setEnabled(true);
    else
        ui->spin_Rotate->setEnabled(false);

    //文字水印
    if ( m_ViewMark.m_iType == 0 )
    {
        ui->widget_Content->setEnabled(true);
        ui->widget_Image->setEnabled(false);
    }
    else
    {
        ui->widget_Content->setEnabled(false);
        ui->widget_Image->setEnabled(true);
    }

    if ( m_ViewMark.m_StyleInfo.m_iPatternType == 0 )
        ui->widget_Offset->setEnabled(false);
    else
        ui->widget_Offset->setEnabled(true);

    _UpdateColorButton();
}
void    DP_ViewMarkWidget::_UpdateContent()
{
    //type
    if ( m_ViewMark.m_iType == 0 )
        ui->radioButton_TextWatermark->setChecked(true);
    else
        ui->radioButton_ImageWatermark->setChecked(true);

    //text
    QFont tFont;
    tFont.setFamily(m_ViewMark.m_FontInfo.m_sFontName);
    ui->fontComboBox->setFont(tFont);

    ui->spinBox_FontSize->setValue(qRound(m_ViewMark.m_FontInfo.m_fFontSize));
    _UpdateColorButton();
    ui->lineEdit_Content->setText(m_ViewMark.m_sContent);

    ui->checkBox_Time->setChecked(m_ViewMark.m_bAddDate);
    ui->checkBox_SysUser->setChecked(m_ViewMark.m_bAddSysUser);
    ui->checkBox_User->setChecked(m_ViewMark.m_bAddUser);

    //image
    ui->lineEdit_ImageFile->setText(m_ViewMark.m_sImageFile);
}
void    DP_ViewMarkWidget::_UpdateColorButton()
{
    if ( ui->pushButton_FontColor->isEnabled() )
        SetButtonColor(ui->pushButton_FontColor, m_ViewMark.m_FontInfo.m_iFontColor);
    else
        SetButtonColor(ui->pushButton_FontColor, m_ViewMark.m_FontInfo.m_iFontColor, 40);
}
void    DP_ViewMarkWidget::_UpdateStyle()
{
    ui->comboBox_Pattern->setCurrentIndex(m_ViewMark.m_StyleInfo.m_iPatternType);
    switch ( m_ViewMark.m_StyleInfo.m_iPatternType )
    {
    case 0:                 //Center
    {
        ui->label_OffsetXTitle->setText(DP_ViewMarkWidget::tr("OffsetX:"));
        ui->label_OffsetYTitle->setText(DP_ViewMarkWidget::tr("OffsetY:"));
        break;
    }
    case 1:             //Title
    {
        ui->label_OffsetXTitle->setText(DP_ViewMarkWidget::tr("SpaceX:"));
        ui->label_OffsetYTitle->setText(DP_ViewMarkWidget::tr("SpaceY:"));
        break;
    }
    case 3:             //Position
    default:
    {
        ui->label_OffsetXTitle->setText(DP_ViewMarkWidget::tr("PosX:"));
        ui->label_OffsetYTitle->setText(DP_ViewMarkWidget::tr("PosY:"));
        break;
    }
    }

    ui->doubleSpinBox_OffsetX->setValue(m_ViewMark.m_StyleInfo.m_fOffsetX);
    ui->doubleSpinBox_OffsetY->setValue(m_ViewMark.m_StyleInfo.m_fOffsetY);
    ui->spin_Zoom->setValue(m_ViewMark.m_StyleInfo.m_fZoom);
    switch ( m_ViewMark.m_StyleInfo.m_iRotate )
    {
    case 45:
    {
        ui->radioButton_Rotate45->setChecked(true);
        break;
    }
    case 0:
    {
        ui->radioButton_Rotate0->setChecked(true);
        break;
    }
    case -45:
    {
        ui->radioButton_Rotate45Neg->setChecked(true);
        break;
    }
    default:
    {
        ui->radioButton_RotateCustom->setChecked(true);
        m_bRotateCustomChecked = true;
        break;
    }
    }

    ui->spin_Rotate->setValue(m_ViewMark.m_StyleInfo.m_iRotate);
    ui->spinBox_Opacity->setValue(m_ViewMark.m_StyleInfo.m_iOpacity);
}
void    DP_ViewMarkWidget::_SaveModify(int iFlag)
{
    DF_Settings* pSettings = m_pReader->GetSettings();
    pSettings->SetConfigBoolValue(DF_SET_VIEWMARK_SHOW, m_ViewMark.m_bShowFlag);
    pSettings->SetConfigBoolValue(DF_SET_VIEWMARK_PRINT, m_ViewMark.m_bPrintFlag);

    //type
    pSettings->SetConfigIntValue(DF_SET_VIEWMARK_TYPE, m_ViewMark.m_iType);

    //add info
    pSettings->SetConfigBoolValue(DF_SET_VIEWMARK_CONTENTDATE, m_ViewMark.m_bAddDate);
    pSettings->SetConfigBoolValue(DF_SET_VIEWMARK_CONTENTSYSUSER, m_ViewMark.m_bAddSysUser);
    pSettings->SetConfigBoolValue(DF_SET_VIEWMARK_CONTENTUSER, m_ViewMark.m_bAddUser);

    //img
    pSettings->SetConfigValue(DF_SET_VIEWMARK_IMGFILE, m_ViewMark.m_sImageFile);

    //content
    pSettings->SetConfigValue(DF_SET_VIEWMARK_CONTENT, m_ViewMark.m_sContent);
    pSettings->SetConfigIntValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_FONT_COLOR, m_ViewMark.m_FontInfo.m_iFontColor);
    pSettings->SetConfigFloatValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_FONT_SIZE, m_ViewMark.m_FontInfo.m_fFontSize);
    pSettings->SetConfigValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_FONT_NAME, m_ViewMark.m_FontInfo.m_sFontName);
    pSettings->SetConfigBoolValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_FONT_ITALIC, m_ViewMark.m_FontInfo.m_bItalic);
    pSettings->SetConfigBoolValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_FONT_BOLD, m_ViewMark.m_FontInfo.m_bBold);
    pSettings->SetConfigBoolValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_FONT_UNDERLINE, m_ViewMark.m_FontInfo.m_bUnderline);

    //style
    pSettings->SetConfigIntValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_STYLE_OPACITY, m_ViewMark.m_StyleInfo.m_iOpacity);
    pSettings->SetConfigFloatValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_STYLE_XSPACE, m_ViewMark.m_StyleInfo.m_fOffsetX);
    pSettings->SetConfigFloatValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_STYLE_YSPACE, m_ViewMark.m_StyleInfo.m_fOffsetY);
    pSettings->SetConfigIntValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_STYLE_ROTATE, m_ViewMark.m_StyleInfo.m_iRotate);
    pSettings->SetConfigIntValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_STYLE_PATTERN, m_ViewMark.m_StyleInfo.m_iPatternType);
    pSettings->SetConfigFloatValue(QString(DF_VIEWMARK_PREFIX) + DF_SUBSET_STYLE_ZOOM, m_ViewMark.m_StyleInfo.m_fZoom);

    m_pReader->GetViewMark()->Reload(m_pReader);
}
void DP_ViewMarkWidget::on_checkBox_ShowViewMark_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_bShowFlag != checked )
    {
        m_ViewMark.m_bShowFlag = checked;
        _UpdateEnable();
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_checkBox_PrintViewMark_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_bPrintFlag != checked )
    {
        m_ViewMark.m_bPrintFlag = checked;
        _UpdateEnable();
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_radioButton_TextWatermark_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_iType != 0 )
    {
        m_ViewMark.m_iType = 0;
        _UpdateEnable();
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_radioButton_ImageWatermark_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_iType != 1 )
    {
        m_ViewMark.m_iType = 1;
        _UpdateEnable();
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_lineEdit_Content_textChanged(const QString &arg1)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_sContent != arg1 )
    {
        m_ViewMark.m_sContent = arg1;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_fontComboBox_activated(const QString &arg1)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_FontInfo.m_sFontName != arg1 )
    {
        m_ViewMark.m_FontInfo.m_sFontName = arg1;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_spinBox_FontSize_valueChanged(int arg1)
{
    if ( !m_bInit )
        return;

    if ( qRound(m_ViewMark.m_FontInfo.m_fFontSize) != arg1 )
    {
        m_ViewMark.m_FontInfo.m_fFontSize = arg1;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_pushButton_FontColor_clicked()
{
    if ( !m_bInit )
        return;

    QColor selColor = QColorDialog::getColor(m_ViewMark.m_FontInfo.m_iFontColor, this);
    if ( selColor.isValid() && selColor.rgb() != (QRgb)m_ViewMark.m_FontInfo.m_iFontColor )
    {
        m_ViewMark.m_FontInfo.m_iFontColor = selColor.rgb();
        _UpdateColorButton();
            m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_lineEdit_ImageFile_textChanged(const QString &arg1)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_sImageFile != arg1 )
    {
        m_ViewMark.m_sImageFile = arg1;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_pushButton_SelectFile_clicked()
{
    if ( !m_bInit )
        return;

    QString sFileFilter = QObject::tr("All file formats(*.bmp *.jpg *.png);;bmp(*.bmp);;jpg(*.jpg);;png(*.png);;other(*.*)");
    QString sFileName = DD_FileDialog::DD_GetOpenFileName(m_pReader, m_pReader->GetDialogParent(), QObject::tr("Open File"), "", sFileFilter);
    if ( sFileName.isEmpty() )
        return;

    m_ViewMark.m_sImageFile = sFileName;
    ui->lineEdit_ImageFile->setText(m_ViewMark.m_sImageFile);
    m_bModify = true;
}
void DP_ViewMarkWidget::on_checkBox_Time_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_bAddDate != checked )
    {
        m_ViewMark.m_bAddDate = checked;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_checkBox_SysUser_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_bAddSysUser != checked )
    {
        m_ViewMark.m_bAddSysUser = checked;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_checkBox_User_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_bAddUser != checked )
    {
        m_ViewMark.m_bAddUser = checked;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_comboBox_Pattern_activated(int index)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_StyleInfo.m_iPatternType != index )
    {
        m_ViewMark.m_StyleInfo.m_iPatternType = index;
        _UpdateEnable();
        _UpdateStyle();
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_spin_Zoom_valueChanged(double arg1)
{
    if ( !m_bInit )
        return;

    if ( qAbs(m_ViewMark.m_StyleInfo.m_fZoom - arg1) > EPSILON_4  )
    {
        m_ViewMark.m_StyleInfo.m_fZoom = arg1;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_doubleSpinBox_OffsetX_valueChanged(double arg1)
{
    if ( !m_bInit )
        return;

    if ( qAbs(m_ViewMark.m_StyleInfo.m_fOffsetX - arg1) > EPSILON_4  )
    {
        m_ViewMark.m_StyleInfo.m_fOffsetX = arg1;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_doubleSpinBox_OffsetY_valueChanged(double arg1)
{
    if ( !m_bInit )
        return;

    if ( qAbs(m_ViewMark.m_StyleInfo.m_fOffsetY - arg1) > EPSILON_4  )
    {
        m_ViewMark.m_StyleInfo.m_fOffsetY = arg1;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_radioButton_Rotate45_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    m_ViewMark.m_StyleInfo.m_iRotate = 45;
    m_bRotateCustomChecked = false;
    _UpdateEnable();
    m_bModify = true;
}
void DP_ViewMarkWidget::on_radioButton_Rotate0_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    m_ViewMark.m_StyleInfo.m_iRotate = 0;
    m_bRotateCustomChecked = false;
    _UpdateEnable();
    m_bModify = true;
}
void DP_ViewMarkWidget::on_radioButton_Rotate45Neg_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    m_ViewMark.m_StyleInfo.m_iRotate = -45;
    m_bRotateCustomChecked = false;
    _UpdateEnable();
    m_bModify = true;
}
void DP_ViewMarkWidget::on_radioButton_RotateCustom_clicked(bool checked)
{
    if ( !m_bInit )
        return;

    m_bRotateCustomChecked = true;
    _UpdateEnable();
}
void DP_ViewMarkWidget::on_spin_Rotate_valueChanged(int arg1)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_StyleInfo.m_iRotate != arg1 )
    {
        m_ViewMark.m_StyleInfo.m_iRotate = arg1;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_horizontalSlider_Opacity_valueChanged(int value)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_StyleInfo.m_iOpacity != value )
    {
        m_ViewMark.m_StyleInfo.m_iOpacity = value;
        m_bModify = true;
    }
}
void DP_ViewMarkWidget::on_spinBox_Opacity_valueChanged(int arg1)
{
    if ( !m_bInit )
        return;

    if ( m_ViewMark.m_StyleInfo.m_iOpacity != arg1 )
    {
        m_ViewMark.m_StyleInfo.m_iOpacity = arg1;
        m_bModify = true;
    }
}
